import os

from dotenv import load_dotenv

load_dotenv()

host = os.getenv("POSTGRES_HOST", "localhost")
user = os.getenv("POSTGRES_USER", "postgres")
password = os.getenv("POSTGRES_PASSWORD", "root")
port = os.getenv("POSTGRES_PORT", "5432")
name = os.getenv("POSTGRES_DB", "fastapi")

ssl_mode = os.getenv("SSL_MODE", "require")

SQLALCHEMY_DATABASE_URL = f"postgresql+psycopg://{user}:{password}@{host}:{port}/"



class ItemReturn:
    quantity = 1


class SubscriptionItem:
    def retrieve(self, id: str = ""):
        return ItemReturn

    def modify(self, id: str, quantity: int):
        return ItemReturn


class StripeAPI:
    def __init__(self, key: str):
        pass

    @property
    def SubscriptionItem(self):
        return SubscriptionItem


def get_stripe_api():
    return StripeAPI("test")



import re

from fastapi.routing import APIRoute


# Swagger operation ID config
def generate_unique_id(route: APIRoute) -> str:
    op_id = re.sub(r"{.*?}", "", route.path_format)  # remove path parameters
    operation_id = re.sub(r"\W", "_", op_id.replace("//", "/"))[
        1:
    ]  # replace non-alphanumeric characters with underscores
    assert route.methods
    # if the route doesn't end with an underscore we should add one
    if operation_id[-1] != "_":
        operation_id += "_"
    # If get method and no {} in the path, it should be called list
    if "GET" in route.methods and "{" not in route.path_format:
        operation_id = operation_id + "list"
    else:
        operation_id = (
            operation_id + list(route.methods)[0].lower()
        )  # add first (and only) method to operation_id
    return operation_id



import os

from dotenv import load_dotenv

load_dotenv()

AUTH0_DOMAIN = os.getenv("AUTH0_DOMAIN")
AUTH0_CLIENT_ID = os.getenv("AUTH0_CLIENT_ID")
AUTH0_CLIENT_SECRET = os.getenv("AUTH0_CLIENT_SECRET")
AUTH0_ALGORIGHM = os.getenv("AUTH0_ALGORIGHM", "RS256")

AUTH0_AUDIENCE = os.getenv("AUTH0_AUDIENCE")
AUTH0_ISSUER = os.getenv("AUTH0_ISSUER")
